import pytest
from unittest.mock import MagicMock, patch
from happtiq_commons_gen_ai.chatgpt_api_service import ChatgptApiService

@pytest.fixture
def chatgpt_api_service():
    return ChatgptApiService(api_key="test-api-key", model="some-model")

def mock_openai_client():
    mock = MagicMock()
    mock.chat.completions.create.return_value = {
        "choices": [
            {
                "message": {
                    "content": "Generated text"
                }
            }
        ]
    }
    return mock

def test_send_prompt_to_api(chatgpt_api_service, monkeypatch):
    monkeypatch.setattr(chatgpt_api_service, "client", mock_openai_client())

    system_message = "You are a helpful assistant."
    text = "Test prompt"
    
    response = chatgpt_api_service.send_prompt_to_api(system_message, text)
    assert response == "Generated text"
    chatgpt_api_service.client.chat.completions.create.assert_called_once_with(
        model="some-model",
        messages=[{"role": "system", "content": system_message}, {"role": "user", "content": text}]
    )

def test_send_prompt_to_api_error(chatgpt_api_service, monkeypatch):
    mock_client = MagicMock()
    mock_client.chat.completions.create.side_effect = Exception("Error generating from chatgpt")
    monkeypatch.setattr(chatgpt_api_service, "client", mock_client)

    system_message = "You are a helpful assistant."
    text = "Test prompt"
    
    with pytest.raises(Exception):
        chatgpt_api_service.send_prompt_to_api(system_message, text)



import pytest
from unittest.mock import MagicMock, patch
from happtiq_commons_gen_ai.gemini_service import GeminiService

@pytest.fixture
def vertex_ai_service(monkeypatch):
    monkeypatch.setattr("google.auth.default", MagicMock(return_value=(MagicMock(),MagicMock())))
    monkeypatch.setattr("vertexai.init", MagicMock())
    return GeminiService(project_id="some-project", location="some-location", model_id="some-model")

def mockGenerativeModel():
    mock = MagicMock()    
    mock.generate_content.return_value = MagicMock(text="Generated text")
    return mock

def test_send_single_data_prompt_to_api(vertex_ai_service, monkeypatch):
    monkeypatch.setattr(vertex_ai_service, "model", mockGenerativeModel())

    prompt = "Test prompt"
    data_file_gcs_uri = "gs://test-bucket/test-file.txt"
    mime_type = "text/plain"
    
    response = vertex_ai_service.send_single_data_prompt_to_api(prompt, data_file_gcs_uri, mime_type)
    assert response == "Generated text"
    vertex_ai_service.model.generate_content.assert_called_once()

def test_send_data_prompt_to_api(vertex_ai_service, monkeypatch):
    monkeypatch.setattr(vertex_ai_service, "model", mockGenerativeModel())
    prompts = ["Test prompt 1", "Test prompt 2"]
    data_file_gcs_uris = ["gs://test-bucket/test-file1.txt", "gs://test-bucket/test-file2.txt"]
    mime_types = ["text/plain", "text/plain"]
    response = vertex_ai_service.send_data_prompt_to_api(prompts, data_file_gcs_uris, mime_types)
    assert response == "Generated text"
    vertex_ai_service.model.generate_content.assert_called_once()
